# Material model generator and explorer

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_matmod/master?urlpath=%2Fapps%2Fbmcs_matmod/slide/slide_explorer.ipynb) - SLIDE 3.2 interface model

## Installation

```bash
pip install .
# or for development
pip install -e .
```

## Usage

```python
import bmcs_matmod
# ...your code...
```

## Testing

```bash
python -m pytest
```

